<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>MX Service Manager</source>
        <translation>MX upravljalnik storitev</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Vklopi ob zagonu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>&amp;Help</source>
        <translation>Pomo&amp;č</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Services enabled at boot</source>
        <translation>Ob zagonu vklopljene storitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Services disabled at boot</source>
        <translation>Ob zagonu izklopljene storitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>search</source>
        <translation>iskanje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>&amp;Stop</source>
        <translation>&amp;Zaustavi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>To orodje izpiše storitve in pritajene programe (procese, ki tečejo v ozadju), ki so bili najdeni na tem sistemu. Pri zaustavljanju teh bodite previdni, saj lahko zaustavite kritično komponento. Najbolje jih je pustiti pri miru, če ne veste kaj so.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>All services</source>
        <translation>Vse storitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Running services</source>
        <translation>Zagnane storitve</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="68"/>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Loading...</source>
        <translation>Nalaganje...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <location filename="../mainwindow.cpp" line="319"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="63"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Ni bilo mogoče določiti sistema za inicializacijo. Program naj bi bil zagnan bodisi s systemd, bodisi s sysvinit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>S&amp;tart</source>
        <translation>Z&amp;aženi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="150"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Izklopi ob zagonu</translation>
    </message>
    <message>
        <source>%1 total services, %2 currently %3running%4</source>
        <translation type="vanished">%1 vseh storitev, %2 trenutnih %3 zagnanih%4</translation>
    </message>
    <message>
        <source>%1 %2enabled%3 at boot, but not running</source>
        <translation type="vanished">%1%2vklopljenih%3 ob zagonu, a ne zagnanih</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Service and daemon manager</source>
        <translation>Upravljanik storitev in pritajenih programov</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Avtorska zaščita (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="319"/>
        <source>Could not enable %1</source>
        <translation>Nisem mogel vklopiti %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="352"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Success</source>
        <translation>Uspešno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 je bil vklopljen ob zagonu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Could not disable %1</source>
        <translation>Nisem mogel izklopiti %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>%1 was disabled.</source>
        <translation>%1 je bil izklopljen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Could not start %1</source>
        <translation>Nisem mogel zagnati %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>%1 was started.</source>
        <translation>%1 je bil zagnan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Could not stop %1</source>
        <translation>Nisem mogel zaustaviti %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>%1 was stopped.</source>
        <translation>%1 je bil zaustavljen.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijavljeni ste kot korenski (root) uporabnik. Odjavite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Ta program je potrebno zagnati s skrbniškim dostopom</translation>
    </message>
    <message>
        <location filename="../service.cpp" line="116"/>
        <source>Could not find service description</source>
        <translation>Opisa storitve ni bilo mogoče najti</translation>
    </message>
</context>
</TS>
